@@ -4,7 +4,7 @@
 # Copyright (C) 2003-2007  Donald N. Allingham
 # Copyright (C) 2007-2008  Brian G. Matherly
 # Copyright (C) 2010       Jakim Friant
-# Copyright (C) 2011-2014  Paul Franklin
+# Copyright (C) 2011-2016  Paul Franklin
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,63 +21,64 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-# Written by Alex Roitman, 
+# Written by Alex Roitman,
 # largely based on the BaseDoc classes by Don Allingham
 
-#-------------------------------------------------------------------------
+"""the non-UI-specific (i.e. common, shared) classes for books"""
+
+# -------------------------------------------------------------------------
 #
 # Standard Python modules
 #
-#-------------------------------------------------------------------------
-from ...const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.gettext
+# -------------------------------------------------------------------------
 import copy
+import os
 
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 #
 # Set up logging
 #
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 import logging
-log = logging.getLogger(".Book")
-import os
 
-#-------------------------------------------------------------------------
+LOG = logging.getLogger(".Book")
+
+# -------------------------------------------------------------------------
 #
 # SAX interface
 #
-#-------------------------------------------------------------------------
-try:
-    from xml.sax import make_parser, handler, SAXParseException
-    from xml.sax.saxutils import escape
-except:
-    from _xmlplus.sax import make_parser, handler, SAXParseException
-    from _xmlplus.sax.saxutils import escape
+# -------------------------------------------------------------------------
+from xml.sax import make_parser, handler, SAXParseException
+from xml.sax.saxutils import escape
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
-# gramps modules
+# Gramps modules
 #
-#-------------------------------------------------------------------------
-from ...const import HOME_DIR
+# -------------------------------------------------------------------------
+from ...const import GRAMPS_LOCALE as glocale
+
+_ = glocale.translation.gettext
+from ...const import USER_DATA
 from ...utils.cast import get_type_converter_by_name, type_name
 from ..docgen import StyleSheet, StyleSheetList
 from .. import BasePluginManager
 from . import book_categories
 
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 #
 # Private Constants
 #
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 _UNSUPPORTED = _("Unsupported")
 
-#------------------------------------------------------------------------
+
+# ------------------------------------------------------------------------
 #
 # Book Item class
 #
-#------------------------------------------------------------------------
-class BookItem(object):
+# ------------------------------------------------------------------------
+class BookItem:
     """
     Interface into the book item -- a smallest element of the book.
     """
@@ -85,8 +86,9 @@ class BookItem(object):
     def __init__(self, dbase, name):
         """
         Create a new empty BookItem.
-        
-        name:   the book item is retrieved 
+        TODO: it should be possible to make a non-empty BookItem, a copy
+
+        name:   the book item is retrieved
                 from the book item registry using name for lookup
         """
         self.dbase = dbase
@@ -101,9 +103,9 @@ class BookItem(object):
                 else:
                     self.category = book_categories[pdata.category]
                 mod = pmgr.load_plugin(pdata)
-                self.write_item = eval('mod.' + pdata.reportclass)
+                self.write_item = getattr(mod, pdata.reportclass)
                 self.name = pdata.id
-                oclass = eval('mod.' + pdata.optionclass)
+                oclass = getattr(mod, pdata.optionclass)
                 self.option_class = oclass(self.name, self.dbase)
                 self.option_class.load_previous_values()
 
@@ -134,7 +136,7 @@ class BookItem(object):
     def set_style_name(self, style_name):
         """
         Set the style name for the item.
-        
+
         style_name: name of the style to set.
         """
         self.style_name = style_name
@@ -145,25 +147,32 @@ class BookItem(object):
         """
         return self.style_name
 
-#------------------------------------------------------------------------
+
+# ------------------------------------------------------------------------
 #
 # Book class
 #
-#------------------------------------------------------------------------
-class Book(object):
+# ------------------------------------------------------------------------
+class Book:
     """
-    Interface into the user-defined book -- a collection of book items.
+    Interface into the user-defined Book -- a collection of book items.
     """
 
-    def __init__(self, obj=None):
+    def __init__(self, obj=None, exact_copy=True):
         """
         Create a new empty Book.
 
-        obj:    if not None, creates the Book from the values in
-                obj, instead of creating an empty Book.
+        @param obj:         if not None, creates the Book from obj, from the
+                            items in obj, instead of creating an empty Book.
+        @type obj:          a :class:`.Book` instance
+        @param exact_copy:  if True (and obj is not None) the exact same
+                            BookItem objects will be in the new Book;
+                            if False (and obj is not None) the same number
+                            and same type of BookItem objects will be created
+        @type exact_copy:   boolean
         """
 
-        self.name = ""
+        self.name = ""  # this is tested for, in several places
         self.dbname = ""
         self.paper_name = None
         self.paper_orientation = None
@@ -172,15 +181,28 @@ class Book(object):
         self.paper_margins = None
         self.paper_format = None
         self.paper_output = None
+        self.item_list = []
         if obj:
-            self.item_list = obj.item_list
-        else:
-            self.item_list = []
-        
+            if exact_copy:
+                self.item_list = obj.item_list
+            else:
+                for item in obj.get_item_list():
+                    new_item = BookItem(item.dbase, item.get_name())
+                    orig_opt_dict = item.option_class.handler.options_dict
+                    new_opt_dict = new_item.option_class.handler.options_dict
+                    menu = new_item.option_class.menu
+                    for optname in orig_opt_dict:
+                        new_opt_dict[optname] = orig_opt_dict[optname]
+                        menu_option = menu.get_option_by_name(optname)
+                        if menu_option:
+                            menu_option.set_value(new_opt_dict[optname])
+                    new_item.set_style_name(item.get_style_name())
+                    self.item_list.append(new_item)
+
     def set_name(self, name):
         """
         Set the name of the book.
-        
+
         name:   the name to set.
         """
         self.name = name
@@ -214,7 +236,7 @@ class Book(object):
     def append_item(self, item):
         """
         Add an item to the book.
-        
+
         item:   an item to append.
         """
         self.item_list.append(item)
@@ -222,8 +244,8 @@ class Book(object):
     def insert_item(self, index, item):
         """
         Inserts an item into the given position in the book.
-        
-        index:  a position index. 
+
+        index:  a position index.
         item:   an item to append.
         """
         self.item_list.insert(index, item)
@@ -231,24 +253,24 @@ class Book(object):
     def pop_item(self, index):
         """
         Pop an item from given position in the book.
-        
-        index:  a position index. 
+
+        index:  a position index.
         """
         return self.item_list.pop(index)
 
     def get_item(self, index):
         """
         Return an item at a given position in the book.
-        
-        index:  a position index. 
+
+        index:  a position index.
         """
         return self.item_list[index]
 
     def set_item(self, index, item):
         """
         Set an item at a given position in the book.
-        
-        index:  a position index. 
+
+        index:  a position index.
         item:   an item to set.
         """
         self.item_list[index] = item
@@ -393,30 +415,32 @@ class Book(object):
         """
         return self.paper_output
 
-#------------------------------------------------------------------------
+
+# ------------------------------------------------------------------------
 #
 # BookList class
 #
-#------------------------------------------------------------------------
-class BookList(object):
+# ------------------------------------------------------------------------
+class BookList:
     """
-    Interface into the user-defined list of books.  
+    Interface into the user-defined list of books.
 
     BookList is loaded from a specified XML file if it exists.
     """
 
     def __init__(self, filename, dbase):
         """
-        Create a new BookList from the books that may be defined in the 
+        Create a new BookList from the books that may be defined in the
         specified file.
 
         file:   XML file that contains book items definitions
         """
         self.dbase = dbase
         self.bookmap = {}
-        self.file = os.path.join(HOME_DIR, filename)
+        self._needs_saving = None
+        self.file = os.path.join(USER_DATA, filename)
         self.parse()
-    
+
     def delete_book(self, name):
         """
         Remove a book from the list. Since each book must have a
@@ -426,12 +450,13 @@ class BookList(object):
         """
         del self.bookmap[name]
 
-    def get_book_map(self):
-        """
-        Return the map of names to books.
-        """
-        return self.bookmap
-
+    ## 2/2016 the string "get_book_map" appears nowhere else in gramps
+    ##    def get_book_map(self):
+    ##        """
+    ##        Return the map of names to books.
+    ##        """
+    ##        return self.bookmap
+    ##
     def get_book(self, name):
         """
         Return the Book associated with the name
@@ -446,92 +471,110 @@ class BookList(object):
 
     def set_book(self, name, book):
         """
-        Add or replaces a Book in the BookList. 
+        Add or replaces a Book in the BookList.
 
         name:   name associated with the Book to add or replace.
-        book:   definition of the Book
+        book:   definition of the book -- a :class:`.Book` instance
         """
         self.bookmap[name] = book
 
+    def set_needs_saving(self, needs_saving):
+        """
+        Set the needs_saving flag for the BookList.
+
+        @param needs_saving: whether the current BookList needs saving
+        @type needs_saving: boolean
+        """
+        self._needs_saving = needs_saving
+
+    def get_needs_saving(self):
+        """
+        Return the needs_saving flag of the BookList.
+
+        @returns: returns whether the current BookList needs saving to a file
+        @rtype: boolean
+        """
+        return self._needs_saving
+
     def save(self):
         """
         Saves the current BookList to the associated file.
         """
         with open(self.file, "w", encoding="utf-8") as b_f:
-            b_f.write("<?xml version=\"1.0\" encoding=\"utf-8\"?>\n")
-            b_f.write('<booklist>\n')
-            for name in sorted(self.bookmap): # enable a diff of archived copies
+            b_f.write('<?xml version="1.0" encoding="utf-8"?>\n')
+            b_f.write("<booklist>\n")
+            for name in sorted(self.bookmap):  # enable a diff of archived copies
                 book = self.get_book(name)
                 dbname = escape(book.get_dbname())
-                b_f.write('  <book name="%s" database="%s">'
-                          '\n' % (escape(name), dbname))
+                b_f.write(
+                    '  <book name="%s" database="%s">' "\n" % (escape(name), dbname)
+                )
                 for item in book.get_item_list():
-                    b_f.write('    <item name="%s" '
-                              'trans_name="%s">\n' % (
-                                  item.get_name(),
-                                  item.get_translated_name()))
+                    b_f.write(
+                        '    <item name="%s" '
+                        'trans_name="%s">\n'
+                        % (item.get_name(), item.get_translated_name())
+                    )
                     options = item.option_class.handler.options_dict
-                    for option_name in sorted(options.keys()): # enable a diff
+                    for option_name in sorted(options.keys()):  # enable a diff
                         option_value = options[option_name]
                         if isinstance(option_value, (list, tuple)):
-                            b_f.write('      <option name="%s" value="" '
-                                      'length="%d">\n' % (
-                                          escape(option_name),
-                                          len(options[option_name])))
-                            for list_index in range(len(option_value)):
-                                option_type = type_name(
-                                    option_value[list_index])
-                                value = escape(str(option_value[list_index]))
-                                value = value.replace('"', '&quot;')
-                                b_f.write('        <listitem number="%d" '
-                                          'type="%s" value="%s"/>\n' % (
-                                              list_index,
-                                              option_type,
-                                              value))
-                            b_f.write('      </option>\n')
+                            b_f.write(
+                                '      <option name="%s" value="" '
+                                'length="%d">\n'
+                                % (escape(option_name), len(options[option_name]))
+                            )
+                            for list_index, v in enumerate(option_value):
+                                option_type = type_name(v)
+                                value = escape(str(v))
+                                value = value.replace('"', "&quot;")
+                                b_f.write(
+                                    '        <listitem number="%d" '
+                                    'type="%s" value="%s"/>\n'
+                                    % (list_index, option_type, value)
+                                )
+                            b_f.write("      </option>\n")
                         else:
                             option_type = type_name(option_value)
                             value = escape(str(option_value))
-                            value = value.replace('"', '&quot;')
-                            b_f.write('      <option name="%s" type="%s" '
-                                      'value="%s"/>\n' % (
-                                          escape(option_name),
-                                          option_type,
-                                          value))
+                            value = value.replace('"', "&quot;")
+                            b_f.write(
+                                '      <option name="%s" type="%s" '
+                                'value="%s"/>\n'
+                                % (escape(option_name), option_type, value)
+                            )
 
-                    b_f.write('      <style name="%s"/>'
-                              '\n' % item.get_style_name())
-                    b_f.write('    </item>\n')
+                    b_f.write('      <style name="%s"/>' "\n" % item.get_style_name())
+                    b_f.write("    </item>\n")
                 if book.get_paper_name():
-                    b_f.write('    <paper name="%s"/>'
-                              '\n' % book.get_paper_name())
-                if book.get_orientation() is not None: # 0 is legal
-                    b_f.write('    <orientation value="%s"/>'
-                              '\n' % book.get_orientation())
-                if book.get_paper_metric() is not None: # 0 is legal
+                    b_f.write('    <paper name="%s"/>' "\n" % book.get_paper_name())
+                if book.get_orientation() is not None:  # 0 is legal
+                    b_f.write(
+                        '    <orientation value="%s"/>' "\n" % book.get_orientation()
+                    )
+                if book.get_paper_metric() is not None:  # 0 is legal
                     b_p_metric = book.get_paper_metric()
                     if isinstance(b_p_metric, bool):
                         b_p_metric = int(b_p_metric)
-                    b_f.write('    <metric value="%s"/>'
-                              '\n' % b_p_metric)
+                    b_f.write('    <metric value="%s"/>' "\n" % b_p_metric)
                 if book.get_custom_paper_size():
                     size = book.get_custom_paper_size()
-                    b_f.write('    <size value="%f %f"/>'
-                              '\n' % (size[0], size[1]))
+                    b_f.write('    <size value="%f %f"/>' "\n" % (size[0], size[1]))
                 if book.get_margins():
-                    for pos in range(len(book.get_margins())):
-                        b_f.write('    <margin number="%s" '
-                                  'value="%f"/>\n' % (
-                                      pos, book.get_margin(pos)))
+                    for pos, margin in enumerate(book.get_margins()):
+                        b_f.write(
+                            '    <margin number="%s" '
+                            'value="%f"/>\n' % (pos, book.get_margin(pos))
+                        )
                 if book.get_format_name():
-                    b_f.write('    <format name="%s"/>'
-                              '\n' % book.get_format_name())
+                    b_f.write('    <format name="%s"/>' "\n" % book.get_format_name())
                 if book.get_output():
-                    b_f.write('    <output name="%s"/>'
-                              '\n' % escape(book.get_output()))
-                b_f.write('  </book>\n')
+                    b_f.write(
+                        '    <output name="%s"/>' "\n" % escape(book.get_output())
+                    )
+                b_f.write("  </book>\n")
 
-            b_f.write('</booklist>\n')
+            b_f.write("</booklist>\n")
 
     def parse(self):
         """
@@ -549,21 +592,27 @@ class BookList(object):
             except UnicodeDecodeError:
                 with open(self.file) as the_file:
                     parser.parse(the_file)
-        except (IOError, OSError, ValueError, SAXParseException, KeyError,
-               AttributeError):
-            pass
+        except (
+            IOError,
+            OSError,
+            ValueError,
+            SAXParseException,
+            KeyError,
+            AttributeError,
+        ):
+            LOG.debug("Failed to parse book list", exc_info=True)
 
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # BookParser
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class BookParser(handler.ContentHandler):
     """
     SAX parsing class for the Books XML file.
     """
-    
+
     def __init__(self, booklist, dbase):
         """
         Create a BookParser class that populates the passed booklist.
@@ -573,25 +622,33 @@ class BookParser(handler.ContentHandler):
         handler.ContentHandler.__init__(self)
         self.dbase = dbase
         self.booklist = booklist
-        self.b = None
-        self.i = None
-        self.o = None
-        self.an_o_name = None
-        self.an_o_value = None
-        self.s = None
+        self.book = None
+        self.item = None
+        self.option = None
+        self.an_opt_name = None
+        self.an_opt_value = None
+        self.style = None
         self.bname = None
         self.iname = None
-        
+        self.dbname = None
+        self.b_p_name = None
+        self.b_p_orient = None
+        self.b_p_metric = None
+        self.b_p_size = None
+        self.b_p_margins = None
+        self.b_p_format = None
+        self.b_p_output = None
+
     def startElement(self, tag, attrs):
         """
         Overridden class that handles the start of a XML element
         """
         if tag == "book":
-            self.b = Book()
-            self.bname = attrs['name']
-            self.b.set_name(self.bname)
-            self.dbname = attrs['database']
-            self.b.set_dbname(self.dbname)
+            self.book = Book()
+            self.bname = attrs["name"]
+            self.book.set_name(self.bname)
+            self.dbname = attrs["database"]
+            self.book.set_dbname(self.dbname)
             self.b_p_name = None
             self.b_p_orient = None
             self.b_p_metric = None
@@ -600,106 +657,109 @@ class BookParser(handler.ContentHandler):
             self.b_p_format = None
             self.b_p_output = None
         elif tag == "item":
-            self.i = BookItem(self.dbase, attrs['name'])
-            self.o = {}
+            self.item = BookItem(self.dbase, attrs["name"])
+            self.option = {}
         elif tag == "option":
-            self.an_o_name = attrs['name']
-            if 'length' in attrs:
-                self.an_o_value = []
+            self.an_opt_name = attrs["name"]
+            if "length" in attrs:
+                self.an_opt_value = []
             else:
-                converter = get_type_converter_by_name(attrs['type'])
-                self.an_o_value = converter(attrs['value'])
+                converter = get_type_converter_by_name(attrs["type"])
+                self.an_opt_value = converter(attrs["value"])
         elif tag == "listitem":
-            converter = get_type_converter_by_name(attrs['type'])
-            self.an_o_value.append(converter(attrs['value']))
+            converter = get_type_converter_by_name(attrs["type"])
+            self.an_opt_value.append(converter(attrs["value"]))
         elif tag == "style":
-            self.s = attrs['name']
-        elif tag == 'paper':
-            self.b_p_name = attrs['name']
-        elif tag == 'orientation':
-            self.b_p_orient = int(attrs['value'])
-        elif tag == 'metric':
-            self.b_p_metric = int(attrs['value'])
-        elif tag == 'size':
-            width, height = attrs['value'].split()
+            self.style = attrs["name"]
+        elif tag == "paper":
+            self.b_p_name = attrs["name"]
+        elif tag == "orientation":
+            self.b_p_orient = int(attrs["value"])
+        elif tag == "metric":
+            self.b_p_metric = int(attrs["value"])
+        elif tag == "size":
+            width, height = attrs["value"].split()
             self.b_p_size = [float(width), float(height)]
-        elif tag == 'margin':
+        elif tag == "margin":
             if self.b_p_margins is None:
                 self.b_p_margins = [0.0, 0.0, 0.0, 0.0]
-            self.b_p_margins[int(attrs['number'])] = float(attrs['value'])
-        elif tag == 'format':
-            self.b_p_format = attrs['name']
-        elif tag == 'output':
-            self.b_p_output = attrs['name']
+            self.b_p_margins[int(attrs["number"])] = float(attrs["value"])
+        elif tag == "format":
+            self.b_p_format = attrs["name"]
+        elif tag == "output":
+            self.b_p_output = attrs["name"]
         else:
             pass
 
     def endElement(self, tag):
-        "Overridden class that handles the end of a XML element"
+        """
+        Overridden class that handles the end of a XML element
+        """
         if tag == "option":
-            self.o[self.an_o_name] = self.an_o_value
+            self.option[self.an_opt_name] = self.an_opt_value
         elif tag == "item":
-            self.i.option_class.handler.options_dict.update(self.o)
-            self.i.set_style_name(self.s)
-            self.b.append_item(self.i)
+            self.item.option_class.handler.options_dict.update(self.option)
+            self.item.set_style_name(self.style)
+            self.book.append_item(self.item)
         elif tag == "book":
             if self.b_p_name:
-                self.b.set_paper_name(self.b_p_name)
-            if self.b_p_orient is not None: # 0 is legal
-                self.b.set_orientation(self.b_p_orient)
-            if self.b_p_metric is not None: # 0 is legal
-                self.b.set_paper_metric(self.b_p_metric)
+                self.book.set_paper_name(self.b_p_name)
+            if self.b_p_orient is not None:  # 0 is legal
+                self.book.set_orientation(self.b_p_orient)
+            if self.b_p_metric is not None:  # 0 is legal
+                self.book.set_paper_metric(self.b_p_metric)
             if self.b_p_size:
-                self.b.set_custom_paper_size(self.b_p_size)
+                self.book.set_custom_paper_size(self.b_p_size)
             if self.b_p_margins:
-                self.b.set_margins(self.b_p_margins)
+                self.book.set_margins(self.b_p_margins)
             if self.b_p_format:
-                self.b.set_format_name(self.b_p_format)
+                self.book.set_format_name(self.b_p_format)
             if self.b_p_output:
-                self.b.set_output(self.b_p_output)
-            self.booklist.set_book(self.bname, self.b)
+                self.book.set_output(self.b_p_output)
+            self.booklist.set_book(self.bname, self.book)
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 # Functions
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 def append_styles(selected_style, item):
     """
     Append the styles for a book item to the stylesheet.
     """
-    handler = item.option_class.handler
+    ihandler = item.option_class.handler
 
     # Set up default style
-    handler.set_default_stylesheet_name(item.get_style_name())
+    ihandler.set_default_stylesheet_name(item.get_style_name())
     default_style = StyleSheet()
     make_default_style = item.option_class.make_default_style
     make_default_style(default_style)
 
     # Read all style sheets available for this item
-    style_file = handler.get_stylesheet_savefile()
+    style_file = ihandler.get_stylesheet_savefile()
     style_list = StyleSheetList(style_file, default_style)
 
     # Get the selected stylesheet
-    style_name = handler.get_default_stylesheet_name()
+    style_name = ihandler.get_default_stylesheet_name()
     style_sheet = style_list.get_style_sheet(style_name)
 
     for this_style_name in style_sheet.get_paragraph_style_names():
         selected_style.add_paragraph_style(
-                this_style_name, 
-                style_sheet.get_paragraph_style(this_style_name))
+            this_style_name, style_sheet.get_paragraph_style(this_style_name)
+        )
 
     for this_style_name in style_sheet.get_draw_style_names():
         selected_style.add_draw_style(
-                this_style_name,
-                style_sheet.get_draw_style(this_style_name))
+            this_style_name, style_sheet.get_draw_style(this_style_name)
+        )
 
     for this_style_name in style_sheet.get_table_style_names():
         selected_style.add_table_style(
-                this_style_name,
-                style_sheet.get_table_style(this_style_name))
+            this_style_name, style_sheet.get_table_style(this_style_name)
+        )
 
     for this_style_name in style_sheet.get_cell_style_names():
         selected_style.add_cell_style(
-                this_style_name,
-                style_sheet.get_cell_style(this_style_name))
+            this_style_name, style_sheet.get_cell_style(this_style_name)
+        )
