@@ -19,34 +19,38 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # GTK libraries
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from gi.repository import Gtk
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Gramps classes
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from gramps.gen.datehandler import displayer
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 # PlaceRefModel
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class PlaceRefModel(Gtk.ListStore):
-
     def __init__(self, obj_list, db):
         Gtk.ListStore.__init__(self, str, str, str, str, object)
         self.db = db
         for obj in obj_list:
             place = self.db.get_place_from_handle(obj.ref)
-            self.append(row=[place.get_gramps_id(),
-                             place.get_name().get_value(),
-                             str(place.get_type()),
-                             displayer.display(obj.date),
-                             obj, ])
+            self.append(
+                row=[
+                    place.get_gramps_id(),
+                    place.get_name().get_value(),
+                    str(place.get_type()),
+                    displayer.display(obj.date),
+                    obj,
+                ]
+            )
