@@ -14,48 +14,58 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-#------------------------------------------------------------------------
+
+# ------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gtk modules
 #
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
+from gi.repository import Gtk
+
+# ------------------------------------------------------------------------
+#
+# Gramps modules
+#
+# ------------------------------------------------------------------------
 from gramps.gen.plug import Gramplet
-from gramps.gen.const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.sgettext
 from gramps.gui.plug.quick import run_quick_report_by_name
 from gramps.gen.lib import Date
+from gramps.gen.const import GRAMPS_LOCALE as glocale
 
-#------------------------------------------------------------------------
+_ = glocale.translation.sgettext
+
+
+# ------------------------------------------------------------------------
 #
 # CalendarGramplet class
 #
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 class CalendarGramplet(Gramplet):
+    """
+    Gramplet showing a calendar of events.
+    """
+
     def init(self):
-        from gi.repository import Gtk
         self.set_tooltip(_("Double-click a day for details"))
         self.gui.calendar = Gtk.Calendar()
-        self.gui.calendar.connect('day-selected-double-click', self.double_click)
+        self.gui.calendar.connect("day-selected-double-click", self.double_click)
         self.gui.calendar.set_display_options(
-                                    Gtk.CalendarDisplayOptions.SHOW_HEADING)
+            Gtk.CalendarDisplayOptions.SHOW_DAY_NAMES
+            | Gtk.CalendarDisplayOptions.SHOW_HEADING
+        )
         self.gui.get_container_widget().remove(self.gui.textview)
-        vbox = Gtk.VBox(homogeneous=False, spacing=0)
+        vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
         vbox.pack_start(self.gui.calendar, False, False, 0)
-        self.gui.get_container_widget().add_with_viewport(vbox)
+        self.gui.get_container_widget().add(vbox)
         vbox.show_all()
-        #self.gui.calendar.show()
-
-    def post_init(self):
-        self.disconnect("active-changed")
 
     def double_click(self, obj):
-        # bring up events on this day
+        """
+        Bring up events on this day.
+        """
         year, month, day = self.gui.calendar.get_date()
         date = Date()
         date.set_yr_mon_day(year, month + 1, day)
-        run_quick_report_by_name(self.gui.dbstate, 
-                                 self.gui.uistate, 
-                                 'onthisday', 
-                                 date)
+        run_quick_report_by_name(self.gui.dbstate, self.gui.uistate, "onthisday", date)
