@@ -19,25 +19,27 @@
 #
 #
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from collections import defaultdict
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from gramps.gen.plug import Gramplet
 from gramps.gen.config import config
 from gramps.gen.const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.gettext
 
 _YIELD_INTERVAL = 350
 
+
 def make_tag_size(n, counts, mins=8, maxs=20):
     # return font sizes mins to maxs
     diff = maxs - mins
@@ -48,16 +50,17 @@ def make_tag_size(n, counts, mins=8, maxs=20):
         position = 0
     return int(position) + mins
 
+
 class GivenNameCloudGramplet(Gramplet):
     def init(self):
         self.set_tooltip(_("Double-click given name for details"))
-        self.top_size = 100 # will be overwritten in load
+        self.top_size = 100  # will be overwritten in load
         self.set_text(_("No Family Tree loaded."))
 
     def db_changed(self):
-        self.connect(self.dbstate.db, 'person-add', self.update)
-        self.connect(self.dbstate.db, 'person-delete', self.update)
-        self.connect(self.dbstate.db, 'person-update', self.update)
+        self.connect(self.dbstate.db, "person-add", self.update)
+        self.connect(self.dbstate.db, "person-delete", self.update)
+        self.connect(self.dbstate.db, "person-update", self.update)
 
     def on_load(self):
         if len(self.gui.data) > 0:
@@ -77,12 +80,12 @@ class GivenNameCloudGramplet(Gramplet):
             allnames = [person.get_primary_name()] + person.get_alternate_names()
             allnames = set(name.get_first_name().strip() for name in allnames)
             for givenname in allnames:
-                nbsp = givenname.split('\u00A0')
-                if len(nbsp) > 1: # there was an NBSP, a non-breaking space
-                    first_two = nbsp[0] + '\u00A0' + nbsp[1].split()[0]
+                nbsp = givenname.split("\u00a0")
+                if len(nbsp) > 1:  # there was an NBSP, a non-breaking space
+                    first_two = nbsp[0] + "\u00a0" + nbsp[1].split()[0]
                     givensubnames[first_two] += 1
                     representative_handle[first_two] = person.handle
-                    givenname = ' '.join(nbsp[1].split()[1:])
+                    givenname = " ".join(nbsp[1].split()[1:])
                 for givensubname in givenname.split():
                     givensubnames[givensubname] += 1
                     representative_handle[givensubname] = person.handle
@@ -95,8 +98,7 @@ class GivenNameCloudGramplet(Gramplet):
 
         total = cnt = 0
         for givensubname in givensubnames:
-            givensubname_sort.append((givensubnames[givensubname],
-                                      givensubname))
+            givensubname_sort.append((givensubnames[givensubname], givensubname))
             total += givensubnames[givensubname]
             cnt += 1
             if not cnt % _YIELD_INTERVAL:
@@ -117,7 +119,7 @@ class GivenNameCloudGramplet(Gramplet):
         ### All done!
         # Now, find out how many we can display without going over top_size:
         totals = defaultdict(int)
-        for (count, givensubname) in cloud_names: # givensubname_sort:
+        for count, givensubname in cloud_names:  # givensubname_sort:
             totals[count] += 1
         sums = sorted(totals, reverse=True)
         total = 0
@@ -132,22 +134,26 @@ class GivenNameCloudGramplet(Gramplet):
 
         self.set_text("")
         showing = 0
-        for (count, givensubname) in cloud_names: # givensubname_sort:
+        for count, givensubname in cloud_names:  # givensubname_sort:
             if count > include_greater_than:
                 if len(givensubname) == 0:
-                    text = config.get('preferences.no-surname-text')
+                    text = config.get("preferences.no-surname-text")
                 else:
                     text = givensubname
                 size = make_tag_size(count, counts)
-                self.link(text, 'Given', text, size,
-                          "%s, %.2f%% (%d)" %
-                          (text,
-                           (float(count)/total_people) * 100,
-                           count))
+                self.link(
+                    text,
+                    "Given",
+                    text,
+                    size,
+                    "%s, %.2f%% (%d)"
+                    % (text, (float(count) / total_people) * 100, count),
+                )
                 self.append_text(" ")
                 showing += 1
 
-        self.append_text(("\n\n" + _("Total unique given names") + ": %d\n") %
-                         total_givensubnames)
+        self.append_text(
+            ("\n\n" + _("Total unique given names") + ": %d\n") % total_givensubnames
+        )
         self.append_text((_("Total given names showing") + ": %d\n") % showing)
         self.append_text((_("Total people") + ": %d") % total_people, "begin")
