@@ -22,19 +22,19 @@
 
 """Tools/Database Processing/Fix Capitalization of Family Names"""
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # gnome/gtk
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from gi.repository import GObject
 from gi.repository import Gtk
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from gramps.gen.db import find_surname_name, DbTxn
 from gramps.gen.const import URL_MANUAL_PAGE
 from gramps.gui.utils import ProgressMeter
@@ -44,75 +44,101 @@ from gramps.gui.managedwindow import ManagedWindow
 from gramps.gui.dialog import OkDialog
 from gramps.gui.plug import tool
 from gramps.gen.const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.sgettext
 from gramps.gui.glade import Glade
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # constants
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 
 prefix_list = [
-    "de", "van", "von", "di", "le", "du", "dela", "della",
-    "des", "vande", "ten", "da", "af", "den", "das", "dello",
-    "del", "en", "ein", "el" "et", "les", "lo", "los", "un",
-    "um", "una", "uno",
-    ]
+    "de",
+    "van",
+    "von",
+    "di",
+    "le",
+    "du",
+    "dela",
+    "della",
+    "des",
+    "vande",
+    "ten",
+    "da",
+    "af",
+    "den",
+    "das",
+    "dello",
+    "del",
+    "en",
+    "ein",
+    "el" "et",
+    "les",
+    "lo",
+    "los",
+    "un",
+    "um",
+    "una",
+    "uno",
+]
 
-WIKI_HELP_PAGE = '%s_-_Tools' % URL_MANUAL_PAGE
-WIKI_HELP_SEC = _('manual|Fix_Capitalization_of_Family_Names')
+WIKI_HELP_PAGE = "%s_-_Tools" % URL_MANUAL_PAGE
+WIKI_HELP_SEC = _("Fix_Capitalization_of_Family_Names", "manual")
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 # ChangeNames
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class ChangeNames(tool.BatchTool, ManagedWindow):
-
     def __init__(self, dbstate, user, options_class, name, callback=None):
         uistate = user.uistate
-        self.label = _('Capitalization changes')
+        self.label = _("Capitalization changes")
         self.cb = callback
 
-        ManagedWindow.__init__(self,uistate,[],self.__class__)
-        self.set_window(Gtk.Window(),Gtk.Label(),'')
+        ManagedWindow.__init__(self, uistate, [], self.__class__)
+        self.set_window(Gtk.Window(), Gtk.Label(), "")
 
         tool.BatchTool.__init__(self, dbstate, user, options_class, name)
         if self.fail:
             return
 
         self.progress = ProgressMeter(
-            _('Checking Family Names'), '', parent=uistate.window)
-        self.progress.set_pass(_('Searching family names'),
-                               len(self.db.get_surname_list()))
+            _("Checking Family Names"), "", parent=uistate.window
+        )
+        self.progress.set_pass(
+            _("Searching family names"), len(self.db.get_surname_list())
+        )
         self.name_list = []
 
         for name in self.db.get_surname_list():
             name.strip()
-            namesplitSP= name.split()
+            namesplitSP = name.split()
             lSP = len(namesplitSP)
-            namesplitHY= name.split('-')
+            namesplitHY = name.split("-")
             lHY = len(namesplitHY)
             if lSP == lHY == 1:
                 if name != name.capitalize():
                     # Single surname without hyphen(s)
                     self.name_list.append(name)
-            #if lSP == 1 and lHY > 1:
-                #print "LSP==1", name, name.capitalize()
-                #if name != name.capitalize():
-                    # Single surname with hyphen(s)
-                    #self.name_list.append(name)
-            if lSP>1 and lHY == 1:
+            # if lSP == 1 and lHY > 1:
+            # print "LSP==1", name, name.capitalize()
+            # if name != name.capitalize():
+            # Single surname with hyphen(s)
+            # self.name_list.append(name)
+            if lSP > 1 and lHY == 1:
                 # more than one string in surname but no hyphen
                 # check if first string is in prefix_list, if so test for cap in rest
                 s1 = 0
                 if namesplitSP[0].lower() in prefix_list:
                     s1 = 1
-                for x in range(len(namesplitSP)-s1):
+                for x in range(len(namesplitSP) - s1):
                     # check if any subsurname is not cap
                     notcap = False
-                    if namesplitSP[s1+x] != namesplitSP[s1+x].capitalize():
+                    if namesplitSP[s1 + x] != namesplitSP[s1 + x].capitalize():
                         notcap = True
                         break
                 if notcap:
@@ -122,7 +148,7 @@ class ChangeNames(tool.BatchTool, ManagedWindow):
                 # more than one string in surname but hyphen(s) exists
                 # check if first string is in prefix_list, if so test for cap
                 if namesplitSP[0].lower() in prefix_list:
-                    namesplitHY[0] = namesplitHY[0].replace(namesplitSP[0],'').strip()
+                    namesplitHY[0] = namesplitHY[0].replace(namesplitSP[0], "").strip()
                 for x in range(len(namesplitHY)):
                     # check if any subsurname is not cap
                     notcap = False
@@ -141,22 +167,24 @@ class ChangeNames(tool.BatchTool, ManagedWindow):
         else:
             self.progress.close()
             self.close()
-            OkDialog(_('No modifications made'),
-                     _("No capitalization changes were detected."),
-                     parent=uistate.window)
+            OkDialog(
+                _("No modifications made"),
+                _("No capitalization changes were detected."),
+                parent=uistate.window,
+            )
 
     def name_cap(self, name):
         name.strip()
         namesplitSP = name.split()
         lSP = len(namesplitSP)
-        lHY = len(name.split('-'))
-        namesep = ' '
+        lHY = len(name.split("-"))
+        namesep = " "
         if lHY > 1:
-            namesep = '-'
-            namesplitSP = name.replace(namesep,' ').split()
-            lSP= len(namesplitSP)
+            namesep = "-"
+            namesplitSP = name.replace(namesep, " ").split()
+            lSP = len(namesplitSP)
         if lSP == lHY == 1:
-            #if name != name.capitalize():
+            # if name != name.capitalize():
             # Single surname without space(s) or hyphen(s), normal case
             return name.capitalize()
         else:
@@ -167,94 +195,97 @@ class ChangeNames(tool.BatchTool, ManagedWindow):
             s1 = 0
             if namesplitSP[0].lower() in prefix_list:
                 s1 = 1
-                result = namesplitSP[0].lower()+ ' '
-            for x in range(lSP-s1):
+                result = namesplitSP[0].lower() + " "
+            for x in range(lSP - s1):
                 # CAP all subsurnames
-                result = result + namesplitSP[s1+x].capitalize() + namesep
+                result = result + namesplitSP[s1 + x].capitalize() + namesep
             return result[:-1]
 
     def display(self):
-
         self.top = Glade()
         window = self.top.toplevel
-        self.top.connect_signals({
-            "destroy_passed_object" : self.close,
-            "on_ok_clicked" : self.on_ok_clicked,
-            "on_help_clicked" : self.on_help_clicked,
-            "on_delete_event"   : self.close,
-            })
+        self.top.connect_signals(
+            {
+                "destroy_passed_object": self.close,
+                "on_ok_clicked": self.on_ok_clicked,
+                "on_help_clicked": self.on_help_clicked,
+                "on_delete_event": self.close,
+            }
+        )
 
         self.list = self.top.get_object("list")
-        self.set_window(window,self.top.get_object('title'),self.label)
-        self.setup_configs('interface.changenames', 500, 450)
+        self.set_window(window, self.top.get_object("title"), self.label)
+        self.setup_configs("interface.changenames", 500, 450)
 
-        self.model = Gtk.ListStore(GObject.TYPE_BOOLEAN, GObject.TYPE_STRING,
-                                   GObject.TYPE_STRING)
+        self.model = Gtk.ListStore(
+            GObject.TYPE_BOOLEAN, GObject.TYPE_STRING, GObject.TYPE_STRING
+        )
 
         r = Gtk.CellRendererToggle()
-        r.connect('toggled',self.toggled)
-        c = Gtk.TreeViewColumn(_('Select'),r,active=0)
+        r.connect("toggled", self.toggled)
+        c = Gtk.TreeViewColumn(_("Select"), r, active=0)
         self.list.append_column(c)
 
-        c = Gtk.TreeViewColumn(_('Original Name'),
-                               Gtk.CellRendererText(),text=1)
+        c = Gtk.TreeViewColumn(_("Original Name"), Gtk.CellRendererText(), text=1)
         self.list.append_column(c)
 
-        c = Gtk.TreeViewColumn(_('Capitalization Change'),
-                               Gtk.CellRendererText(),text=2)
+        c = Gtk.TreeViewColumn(
+            _("Capitalization Change"), Gtk.CellRendererText(), text=2
+        )
         self.list.append_column(c)
 
         self.list.set_model(self.model)
 
         self.iter_list = []
-        self.progress.set_pass(_('Building display'),len(self.name_list))
+        self.progress.set_pass(_("Building display"), len(self.name_list))
         for name in self.name_list:
             handle = self.model.append()
-            self.model.set_value(handle,0,True)
-            self.model.set_value(handle,1, name)
+            self.model.set_value(handle, 0, True)
+            self.model.set_value(handle, 1, name)
             namecap = self.name_cap(name)
-            self.model.set_value(handle,2, namecap)
+            self.model.set_value(handle, 2, namecap)
             self.iter_list.append(handle)
             self.progress.step()
         self.progress.close()
 
         self.show()
 
-    def toggled(self,cell,path_string):
-        path = tuple(map(int, path_string.split(':')))
+    def toggled(self, cell, path_string):
+        path = tuple(map(int, path_string.split(":")))
         row = self.model[path]
         row[0] = not row[0]
 
     def build_menu_names(self, obj):
-        return (self.label,None)
+        return (self.label, None)
 
     def on_help_clicked(self, obj):
         """Display the relevant portion of Gramps manual"""
-        display_help(WIKI_HELP_PAGE , WIKI_HELP_SEC)
+        display_help(WIKI_HELP_PAGE, WIKI_HELP_SEC)
 
     def on_ok_clicked(self, obj):
-        with DbTxn(_("Capitalization changes"), self.db, batch=True
-                   ) as self.trans:
+        with DbTxn(_("Capitalization changes"), self.db, batch=True) as self.trans:
             self.db.disable_signals()
-            changelist = set(self.model.get_value(node,1)
-                            for node in self.iter_list
-                                if self.model.get_value(node,0))
+            changelist = set(
+                self.model.get_value(node, 1)
+                for node in self.iter_list
+                if self.model.get_value(node, 0)
+            )
 
-            #with self.db.get_person_cursor(update=True, commit=True) as cursor:
+            # with self.db.get_person_cursor(update=True, commit=True) as cursor:
             #  for handle, data in cursor:
             for handle in self.db.get_person_handles(False):
                 person = self.db.get_person_from_handle(handle)
-                #person = Person(data)
+                # person = Person(data)
                 change = False
                 for name in [person.get_primary_name()] + person.get_alternate_names():
-                    sname = find_surname_name(handle, name.serialize())
+                    sname = find_surname_name(name.surname_list)
                     if sname in changelist:
                         change = True
                         for surn in name.get_surname_list():
                             sname = self.name_cap(surn.get_surname())
                             surn.set_surname(sname)
                 if change:
-                    #cursor.update(handle, person.serialize())
+                    # cursor.update(handle, person.serialize())
                     self.db.commit_person(person, self.trans)
 
         self.db.enable_signals()
@@ -265,15 +296,16 @@ class ChangeNames(tool.BatchTool, ManagedWindow):
         self.close()
         self.cb()
 
-#------------------------------------------------------------------------
+
+# ------------------------------------------------------------------------
 #
 #
 #
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 class ChangeNamesOptions(tool.ToolOptions):
     """
     Defines options and provides handling interface.
     """
 
-    def __init__(self, name,person_id=None):
-        tool.ToolOptions.__init__(self, name,person_id)
+    def __init__(self, name, person_id=None):
+        tool.ToolOptions.__init__(self, name, person_id)
